==> quarkus-core-3.8.1-sources.jar: io/quarkus/runtime/logging/SyslogConfig$$accessor.java <==
package io.quarkus.runtime.logging;
@io.quarkus.Generated("Quarkus annotation processor")
public final class SyslogConfig$$accessor {
    private SyslogConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_enable(Object __instance) {
        return ((SyslogConfig)__instance).enable;
    }
    @SuppressWarnings("unchecked")
    public static void set_enable(Object __instance, boolean enable) {
        ((SyslogConfig)__instance).enable = enable;
    }
    @SuppressWarnings("unchecked")
    public static Object get_endpoint(Object __instance) {
        return ((SyslogConfig)__instance).endpoint;
    }
    @SuppressWarnings("unchecked")
    public static void set_endpoint(Object __instance, Object endpoint) {
        ((SyslogConfig)__instance).endpoint = (java.net.InetSocketAddress)endpoint;
    }
    @SuppressWarnings("unchecked")
    public static Object get_appName(Object __instance) {
        return ((SyslogConfig)__instance).appName;
    }
    @SuppressWarnings("unchecked")
    public static void set_appName(Object __instance, Object appName) {
        ((SyslogConfig)__instance).appName = (java.util.Optional<String>)appName;
    }
    @SuppressWarnings("unchecked")
    public static Object get_hostname(Object __instance) {
        return ((SyslogConfig)__instance).hostname;
    }
    @SuppressWarnings("unchecked")
    public static void set_hostname(Object __instance, Object hostname) {
        ((SyslogConfig)__instance).hostname = (java.util.Optional<String>)hostname;
    }
    @SuppressWarnings("unchecked")
    public static Object get_facility(Object __instance) {
        return ((SyslogConfig)__instance).facility;
    }
    @SuppressWarnings("unchecked")
    public static void set_facility(Object __instance, Object facility) {
        ((SyslogConfig)__instance).facility = (org.jboss.logmanager.handlers.SyslogHandler.Facility)facility;
    }
    @SuppressWarnings("unchecked")
    public static Object get_syslogType(Object __instance) {
        return ((SyslogConfig)__instance).syslogType;
    }
    @SuppressWarnings("unchecked")
    public static void set_syslogType(Object __instance, Object syslogType) {
        ((SyslogConfig)__instance).syslogType = (org.jboss.logmanager.handlers.SyslogHandler.SyslogType)syslogType;
    }
    @SuppressWarnings("unchecked")
    public static Object get_protocol(Object __instance) {
        return ((SyslogConfig)__instance).protocol;
    }
    @SuppressWarnings("unchecked")
    public static void set_protocol(Object __instance, Object protocol) {
        ((SyslogConfig)__instance).protocol = (org.jboss.logmanager.handlers.SyslogHandler.Protocol)protocol;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_useCountingFraming(Object __instance) {
        return ((SyslogConfig)__instance).useCountingFraming;
    }
    @SuppressWarnings("unchecked")
    public static void set_useCountingFraming(Object __instance, boolean useCountingFraming) {
        ((SyslogConfig)__instance).useCountingFraming = useCountingFraming;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_truncate(Object __instance) {
        return ((SyslogConfig)__instance).truncate;
    }
    @SuppressWarnings("unchecked")
    public static void set_truncate(Object __instance, boolean truncate) {
        ((SyslogConfig)__instance).truncate = truncate;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_blockOnReconnect(Object __instance) {
        return ((SyslogConfig)__instance).blockOnReconnect;
    }
    @SuppressWarnings("unchecked")
    public static void set_blockOnReconnect(Object __instance, boolean blockOnReconnect) {
        ((SyslogConfig)__instance).blockOnReconnect = blockOnReconnect;
    }
    @SuppressWarnings("unchecked")
    public static Object get_format(Object __instance) {
        return ((SyslogConfig)__instance).format;
    }
    @SuppressWarnings("unchecked")
    public static void set_format(Object __instance, Object format) {
        ((SyslogConfig)__instance).format = (String)format;
    }
    @SuppressWarnings("unchecked")
    public static Object get_level(Object __instance) {
        return ((SyslogConfig)__instance).level;
    }
    @SuppressWarnings("unchecked")
    public static void set_level(Object __instance, Object level) {
        ((SyslogConfig)__instance).level = (java.util.logging.Level)level;
    }
    @SuppressWarnings("unchecked")
    public static Object get_filter(Object __instance) {
        return ((SyslogConfig)__instance).filter;
    }
    @SuppressWarnings("unchecked")
    public static void set_filter(Object __instance, Object filter) {
        ((SyslogConfig)__instance).filter = (java.util.Optional<String>)filter;
    }
    @SuppressWarnings("unchecked")
    public static Object get_async(Object __instance) {
        return ((SyslogConfig)__instance).async;
    }
    @SuppressWarnings("unchecked")
    public static void set_async(Object __instance, Object async) {
        ((SyslogConfig)__instance).async = (AsyncConfig)async;
    }
}

==> quarkus-core-3.16.1-sources.jar: io/quarkus/runtime/logging/SyslogConfig$$accessor.java <==
package io.quarkus.runtime.logging;
@io.quarkus.Generated("Quarkus annotation processor")
public final class SyslogConfig$$accessor {
    private SyslogConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_enable(Object __instance) {
        return ((SyslogConfig)__instance).enable;
    }
    @SuppressWarnings("unchecked")
    public static void set_enable(Object __instance, boolean enable) {
        ((SyslogConfig)__instance).enable = enable;
    }
    @SuppressWarnings("unchecked")
    public static Object get_endpoint(Object __instance) {
        return ((SyslogConfig)__instance).endpoint;
    }
    @SuppressWarnings("unchecked")
    public static void set_endpoint(Object __instance, Object endpoint) {
        ((SyslogConfig)__instance).endpoint = (java.net.InetSocketAddress)endpoint;
    }
    @SuppressWarnings("unchecked")
    public static Object get_appName(Object __instance) {
        return ((SyslogConfig)__instance).appName;
    }
    @SuppressWarnings("unchecked")
    public static void set_appName(Object __instance, Object appName) {
        ((SyslogConfig)__instance).appName = (java.util.Optional<String>)appName;
    }
    @SuppressWarnings("unchecked")
    public static Object get_hostname(Object __instance) {
        return ((SyslogConfig)__instance).hostname;
    }
    @SuppressWarnings("unchecked")
    public static void set_hostname(Object __instance, Object hostname) {
        ((SyslogConfig)__instance).hostname = (java.util.Optional<String>)hostname;
    }
    @SuppressWarnings("unchecked")
    public static Object get_facility(Object __instance) {
        return ((SyslogConfig)__instance).facility;
    }
    @SuppressWarnings("unchecked")
    public static void set_facility(Object __instance, Object facility) {
        ((SyslogConfig)__instance).facility = (org.jboss.logmanager.handlers.SyslogHandler.Facility)facility;
    }
    @SuppressWarnings("unchecked")
    public static Object get_syslogType(Object __instance) {
        return ((SyslogConfig)__instance).syslogType;
    }
    @SuppressWarnings("unchecked")
    public static void set_syslogType(Object __instance, Object syslogType) {
        ((SyslogConfig)__instance).syslogType = (org.jboss.logmanager.handlers.SyslogHandler.SyslogType)syslogType;
    }
    @SuppressWarnings("unchecked")
    public static Object get_protocol(Object __instance) {
        return ((SyslogConfig)__instance).protocol;
    }
    @SuppressWarnings("unchecked")
    public static void set_protocol(Object __instance, Object protocol) {
        ((SyslogConfig)__instance).protocol = (org.jboss.logmanager.handlers.SyslogHandler.Protocol)protocol;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_useCountingFraming(Object __instance) {
        return ((SyslogConfig)__instance).useCountingFraming;
    }
    @SuppressWarnings("unchecked")
    public static void set_useCountingFraming(Object __instance, boolean useCountingFraming) {
        ((SyslogConfig)__instance).useCountingFraming = useCountingFraming;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_truncate(Object __instance) {
        return ((SyslogConfig)__instance).truncate;
    }
    @SuppressWarnings("unchecked")
    public static void set_truncate(Object __instance, boolean truncate) {
        ((SyslogConfig)__instance).truncate = truncate;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_blockOnReconnect(Object __instance) {
        return ((SyslogConfig)__instance).blockOnReconnect;
    }
    @SuppressWarnings("unchecked")
    public static void set_blockOnReconnect(Object __instance, boolean blockOnReconnect) {
        ((SyslogConfig)__instance).blockOnReconnect = blockOnReconnect;
    }
    @SuppressWarnings("unchecked")
    public static Object get_format(Object __instance) {
        return ((SyslogConfig)__instance).format;
    }
    @SuppressWarnings("unchecked")
    public static void set_format(Object __instance, Object format) {
        ((SyslogConfig)__instance).format = (String)format;
    }
    @SuppressWarnings("unchecked")
    public static Object get_level(Object __instance) {
        return ((SyslogConfig)__instance).level;
    }
    @SuppressWarnings("unchecked")
    public static void set_level(Object __instance, Object level) {
        ((SyslogConfig)__instance).level = (java.util.logging.Level)level;
    }
    @SuppressWarnings("unchecked")
    public static Object get_filter(Object __instance) {
        return ((SyslogConfig)__instance).filter;
    }
    @SuppressWarnings("unchecked")
    public static void set_filter(Object __instance, Object filter) {
        ((SyslogConfig)__instance).filter = (java.util.Optional<String>)filter;
    }
    @SuppressWarnings("unchecked")
    public static Object get_maxLength(Object __instance) {
        return ((SyslogConfig)__instance).maxLength;
    }
    @SuppressWarnings("unchecked")
    public static void set_maxLength(Object __instance, Object maxLength) {
        ((SyslogConfig)__instance).maxLength = (java.util.Optional<io.quarkus.runtime.configuration.MemorySize>)maxLength;
    }
    @SuppressWarnings("unchecked")
    public static Object get_async(Object __instance) {
        return ((SyslogConfig)__instance).async;
    }
    @SuppressWarnings("unchecked")
    public static void set_async(Object __instance, Object async) {
        ((SyslogConfig)__instance).async = (AsyncConfig)async;
    }
}
